@@ -20,14 +20,12 @@
 # unittests for field Tags running Tango Server
 #
 import unittest
-# import os
 import sys
-# import random
-# import struct
-# import binascii
 import time
-# import threading
-import PyTango
+try:
+    import tango
+except Exception:
+    import PyTango as tango
 from os.path import expanduser
 # import json
 # from nxstools import nxscreate
@@ -80,10 +78,10 @@ class NXSCreateOnlineCPDBTest(
         while not found and cnt < 1000:
             try:
                 sys.stdout.write(".")
-                xmlc = PyTango.DeviceProxy(
+                xmlc = tango.DeviceProxy(
                     sv.new_device_info_writer.name)
                 time.sleep(0.01)
-                if xmlc.state() == PyTango.DevState.ON:
+                if xmlc.state() == tango.DevState.ON:
                     found = True
                 found = True
             except Exception as e:
@@ -99,7 +97,7 @@ class NXSCreateOnlineCPDBTest(
                 "Cannot connect to %s"
                 % sv.new_device_info_writer.name)
 
-        if xmlc.state() == PyTango.DevState.ON:
+        if xmlc.state() == tango.DevState.ON:
             xmlc.JSONSettings = args
             xmlc.Open()
         version = xmlc.version
@@ -108,16 +106,16 @@ class NXSCreateOnlineCPDBTest(
         self.version = ".".join(vv[0:3])
         self.label = ".".join(vv[3:-1])
 
-        self.assertEqual(xmlc.state(), PyTango.DevState.OPEN)
+        self.assertEqual(xmlc.state(), tango.DevState.OPEN)
         return xmlc
 
     # closes opens config server
     # \param xmlc XMLConfigurator instance
     def closeConfig(self):
-        self.assertEqual(self._proxy.state(), PyTango.DevState.OPEN)
+        self.assertEqual(self._proxy.state(), tango.DevState.OPEN)
 
         self._proxy.Close()
-        self.assertEqual(self._proxy.state(), PyTango.DevState.ON)
+        self.assertEqual(self._proxy.state(), tango.DevState.ON)
 
     # test starter
     # \brief Common set up
